==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Trang nh&agrave;',
'articles' => 'B&agrave;i',
'articles_auteur' => 'B&agrave;i v&#7903; c&#7911;a t&aacute;c gi&#7843; n&agrave;y',
'articles_populaires' => 'Nh&#7919;ng b&agrave;i &#273;&#432;&#7907;c chu&#7897;ng nh&#7845;t',
'articles_rubrique' => 'B&agrave;i v&#7903; c&#7911;a &#273;&#7873; m&#7909;c n&agrave;y',
'aucun_article' => 'Kh&ocirc;ng c&oacute; b&agrave;i t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y  ',
'aucun_auteur' => 'Kh&ocirc;ng c&oacute; t&aacute;c gi&#7843; t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y',
'aucun_site' => 'Kh&ocirc;ng c&oacute; trang Web t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y ',
'aucune_breve' => 'Kh&ocirc;ng c&oacute; tin ng&#7855;n t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y',
'aucune_rubrique' => 'Kh&ocirc;ng c&oacute; &#273;&#7873; m&#7909;c t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y',
'autres' => '<NEW>Autres',
'autres_breves' => 'Nh&#7919;ng tin ng&#7857;n kh&aacute;c ',
'autres_groupes_mots_clefs' => 'Nh&#7919;ng nh&oacute;m t&#7915; then ch&#7889;t kh&aacute;c ',
'autres_sites' => 'Nh&#7919;ng trang Web kh&aacute;c',

// B
'bonjour' => 'Th&acirc;n ch&agrave;o',
'breves' => 'Tin ng&#7855;n',

// C
'commenter_site' => 'Ph&ecirc; b&igrave;nh trang Web n&agrave;y',
'copie_document_impossible' => '<NEW>Impossible de copier le document',

// D
'date' => 'Ng&agrave;y',
'dernier_ajout' => 'B&agrave;i &#273;&#432;&#7907;c th&ecirc;m sau ch&oacute;t',
'dernieres_breves' => 'Nh&#7919;ng tin ng&#7855;n m&#7899;i nh&#7845;t ',
'derniers_articles' => 'Nh&#7919;ng b&agrave;i m&#7899;i nh&#7845;t ',
'derniers_commentaires' => 'C&aacute;c g&oacute;p &yacute; m&#7899;i nh&#7845;t',
'derniers_messages_forum' => 'Trao &#273;&#7893;i m&#7899;i nh&#7845;t hi&#7879;n trong di&#7877;n &#273;&agrave;n',
'documents_interdits_forum' => '<NEW>Documents interdits dans le forum',

// E
'edition_mode_texte' => 'v&#259;n b&#7843;n th&#432;&#7901;ng',
'en_reponse' => 'Tr&#7843; l&#7901;i cho&nbsp;:',
'en_resume' => 'T&oacute;m t&#7855;t',
'envoyer_message' => 'G&#7917;i th&#432; t&iacute;n m&#7899;i',
'espace_prive' => 'M&#7841;ng c&aacute; nh&acirc;n',

// F
'formats_acceptes' => '<NEW>Formats accept&#233;s : @formats@.',
'forum' => 'Di&#7877;n &#273;&agrave;n',

// H
'hierarchie_site' => 'C&#7845;u tr&uacute;c th&#7913; b&#7853;c c&#7911;a trang web',

// J
'jours' => 'ng&agrave;y',

// L
'lien_connecter' => '<NEW>Se connecter',

// M
'meme_auteur' => 'C&ugrave;ng t&aacute;c gi&#7843;',
'meme_rubrique' => 'Trong c&ugrave;ng &#273;&#7873; m&#7909;c',
'memes_auteurs' => 'C&ugrave;ng t&aacute;c gi&#7843;',
'message' => 'Th&#432; t&iacute;n',
'messages_forum' => 'Th&#432; t&iacute;n di&#7877;n &#273;&agrave;n',
'messages_recents' => 'Tin m&#7899;i nh&#7845;t trong di&#7877;n &#273;&agrave;n',
'mots_clefs' => 'T&#7915; then ch&#7889;t',
'mots_clefs_meme_groupe' => 'T&#7915; then ch&#7889;t c&ugrave;ng nh&ograve;m  ',

// N
'navigation' => '&#272;i&#7873;u h&#432;&#7899;ng',
'nom' => 'T&ecirc;n',
'nouveautes' => 'Nh&#7919;ng &#273;i&#7875;m m&#7899;i',
'nouveautes_web' => 'Nh&#7919;ng &#273;i&#7873;u m&#7899;i tr&ecirc;n trang web',
'nouveaux_articles' => 'B&agrave;i m&#7899;i',
'nouvelles_breves' => 'Tin ng&#7855;n m&#7899;i',

// P
'page_precedente' => 'trang tr&#432;&#7899;c',
'page_suivante' => 'trang sau',
'par_auteur' => 'b&#7903;i',
'participer_site' => 'B&#7841;n c&oacute; th&#7875; tham gia &#273;&oacute;ng g&oacute;p t&iacute;ch c&#7921;c v&agrave;o trang web n&agrave;y &#273;&#7875; so&#7841;n v&agrave; &#273;&#259;ng b&agrave;i v&#7903;. B&#7841;n ph&#7843;i ghi danh d&#432;&#7899;i &#273;&acirc;y. Sau &#273;&oacute; b&#7841;n s&#7869; nh&#7853;n email cho bi&#7871;t chi ti&#7871;t &#273;&#7875; v&agrave;o trang web.',
'plan_site' => 'S&#417; &#273;&#7891;',
'popularite' => 'M&#7913;c &#273;&#7897; ph&#7893; th&ocirc;ng',
'poster_message' => '&#272;&#7875; &#273;&#259;ng tin',
'proposer_site' => 'B&#7841;n c&oacute; th&#7875; &#273;&#7873; ngh&#7883; th&ecirc;m m&#7897;t trang web v&agrave;o ph&#7847;n n&agrave;y:',

// R
'repondre_article' => 'Tr&#7843; l&#7901;i b&agrave;i n&agrave;y',
'repondre_breve' => 'Tr&#7843; l&#7901;i tin ng&#7855;n n&agrave;y',
'repondre_message' => 'Tr&#7843; l&#7901;i m&#7851;u tin n&agrave;y',
'resultats_recherche' => 'K&#7871;t qu&#7843; t&igrave;m ki&#7871;m',
'retour_debut_forums' => 'Tr&#7903; v&#7873; trang &#273;&#7847;u c&#7911;a di&#7877;n &#273;&agrave;n',
'rubrique' => '&ETH;&#7873; M&#7909;c',
'rubriques' => '&ETH;&#7873; M&#7909;c',

// S
'signatures_petition' => 'Ch&#7919; k&yacute;',
'site_realise_avec_spip' => 'Trang web &#273;&#432;&#7907;c so&#7841;n b&#7857;ng SPIP',
'sites_web' => 'Trang web',
'sous_rubriques' => '&#272;&#7873; m&#7909;c ph&#7909;',
'spam' => '<NEW>Spam',
'suite' => 'ti&#7871;p t&#7909;c',
'sur_web' => 'Tr&ecirc;n trang web',
'syndiquer_rubrique' => 'Ph&#7893; bi&#7871;n &#273;&#7873; m&#7909;c n&agrave;y',
'syndiquer_site' => 'Ph&#7893; bi&#7871;n tr&#7885;n trang web',

// T
'texte_lettre_information' => '&#272;&acirc;y l&agrave; b&#7843;n tin c&#7911;a trang web',
'texte_lettre_information_2' => 'T&oacute;m t&#7855;t c&aacute;c b&agrave;i v&#7903; v&agrave; tin ng&#7855;n &#273;&atilde; ph&aacute;t h&agrave;nh t&#7915; ',

// V
'ver_imprimer' => 'Ki&#7875;u d&#7875; in',
'voir_en_ligne' => 'Xem online',
'voir_squelette' => '<NEW>voir le squelette de cette page'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Trang nh&agrave;',
'article' => 'Article', # NEW
'articles' => 'B&agrave;i',
'articles_auteur' => 'B&agrave;i v&#7903; c&#7911;a t&aacute;c gi&#7843; n&agrave;y',
'articles_populaires' => 'Nh&#7919;ng b&agrave;i &#273;&#432;&#7907;c chu&#7897;ng nh&#7845;t',
'articles_rubrique' => 'B&agrave;i v&#7903; c&#7911;a &#273;&#7873; m&#7909;c n&agrave;y',
'aucun_article' => 'Kh&ocirc;ng c&oacute; b&agrave;i t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y  ',
'aucun_auteur' => 'Kh&ocirc;ng c&oacute; t&aacute;c gi&#7843; t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y',
'aucun_site' => 'Kh&ocirc;ng c&oacute; trang Web t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y ',
'aucune_breve' => 'Kh&ocirc;ng c&oacute; tin ng&#7855;n t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y',
'aucune_rubrique' => 'Kh&ocirc;ng c&oacute; &#273;&#7873; m&#7909;c t&#7841;i &#273;&#7883;a ch&igrave; n&agrave;y',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Nh&#7919;ng tin ng&#7857;n kh&aacute;c ',
'autres_groupes_mots_clefs' => 'Nh&#7919;ng nh&oacute;m t&#7915; then ch&#7889;t kh&aacute;c ',
'autres_sites' => 'Nh&#7919;ng trang Web kh&aacute;c',

// B
'bonjour' => 'Th&acirc;n ch&agrave;o',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Tin ng&#7855;n',

// C
'commenter_site' => 'Ph&ecirc; b&igrave;nh trang Web n&agrave;y',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Ng&agrave;y',
'dernier_ajout' => 'B&agrave;i &#273;&#432;&#7907;c th&ecirc;m sau ch&oacute;t',
'dernieres_breves' => 'Nh&#7919;ng tin ng&#7855;n m&#7899;i nh&#7845;t ',
'derniers_articles' => 'Nh&#7919;ng b&agrave;i m&#7899;i nh&#7845;t ',
'derniers_commentaires' => 'C&aacute;c g&oacute;p &yacute; m&#7899;i nh&#7845;t',
'derniers_messages_forum' => 'Trao &#273;&#7893;i m&#7899;i nh&#7845;t hi&#7879;n trong di&#7877;n &#273;&agrave;n',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'v&#259;n b&#7843;n th&#432;&#7901;ng',
'en_reponse' => 'Tr&#7843; l&#7901;i cho&nbsp;:',
'en_resume' => 'T&oacute;m t&#7855;t',
'envoyer_message' => 'G&#7917;i th&#432; t&iacute;n m&#7899;i',
'espace_prive' => 'M&#7841;ng c&aacute; nh&acirc;n',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Di&#7877;n &#273;&agrave;n',

// H
'hierarchie_site' => 'C&#7845;u tr&uacute;c th&#7913; b&#7853;c c&#7911;a trang web',

// J
'jours' => 'ng&agrave;y',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'C&ugrave;ng t&aacute;c gi&#7843;',
'meme_rubrique' => 'Trong c&ugrave;ng &#273;&#7873; m&#7909;c',
'memes_auteurs' => 'C&ugrave;ng t&aacute;c gi&#7843;',
'message' => 'Th&#432; t&iacute;n',
'messages_forum' => 'Th&#432; t&iacute;n di&#7877;n &#273;&agrave;n',
'messages_recents' => 'Tin m&#7899;i nh&#7845;t trong di&#7877;n &#273;&agrave;n',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'T&#7915; then ch&#7889;t',
'mots_clefs_meme_groupe' => 'T&#7915; then ch&#7889;t c&ugrave;ng nh&ograve;m  ',

// N
'navigation' => '&#272;i&#7873;u h&#432;&#7899;ng',
'nom' => 'T&ecirc;n',
'nouveautes' => 'Nh&#7919;ng &#273;i&#7875;m m&#7899;i',
'nouveautes_web' => 'Nh&#7919;ng &#273;i&#7873;u m&#7899;i tr&ecirc;n trang web',
'nouveaux_articles' => 'B&agrave;i m&#7899;i',
'nouvelles_breves' => 'Tin ng&#7855;n m&#7899;i',

// P
'page_precedente' => 'trang tr&#432;&#7899;c',
'page_suivante' => 'trang sau',
'par_auteur' => 'b&#7903;i',
'participer_site' => 'B&#7841;n c&oacute; th&#7875; tham gia &#273;&oacute;ng g&oacute;p t&iacute;ch c&#7921;c v&agrave;o trang web n&agrave;y &#273;&#7875; so&#7841;n v&agrave; &#273;&#259;ng b&agrave;i v&#7903;. B&#7841;n ph&#7843;i ghi danh d&#432;&#7899;i &#273;&acirc;y. Sau &#273;&oacute; b&#7841;n s&#7869; nh&#7853;n email cho bi&#7871;t chi ti&#7871;t &#273;&#7875; v&agrave;o trang web.',
'plan_site' => 'S&#417; &#273;&#7891;',
'popularite' => 'M&#7913;c &#273;&#7897; ph&#7893; th&ocirc;ng',
'poster_message' => '&#272;&#7875; &#273;&#259;ng tin',
'proposer_site' => 'B&#7841;n c&oacute; th&#7875; &#273;&#7873; ngh&#7883; th&ecirc;m m&#7897;t trang web v&agrave;o ph&#7847;n n&agrave;y:',

// R
'repondre_article' => 'Tr&#7843; l&#7901;i b&agrave;i n&agrave;y',
'repondre_breve' => 'Tr&#7843; l&#7901;i tin ng&#7855;n n&agrave;y',
'repondre_message' => 'Tr&#7843; l&#7901;i m&#7851;u tin n&agrave;y',
'resultats_recherche' => 'K&#7871;t qu&#7843; t&igrave;m ki&#7871;m',
'retour_debut_forums' => 'Tr&#7903; v&#7873; trang &#273;&#7847;u c&#7911;a di&#7877;n &#273;&agrave;n',
'rubrique' => '&ETH;&#7873; M&#7909;c',
'rubriques' => '&ETH;&#7873; M&#7909;c',

// S
'signatures_petition' => 'Ch&#7919; k&yacute;',
'site_realise_avec_spip' => 'Trang web &#273;&#432;&#7907;c so&#7841;n b&#7857;ng SPIP',
'sites_web' => 'Trang web',
'sous_rubriques' => '&#272;&#7873; m&#7909;c ph&#7909;',
'spam' => 'Spam', # NEW
'suite' => 'ti&#7871;p t&#7909;c',
'sur_web' => 'Tr&ecirc;n trang web',
'syndiquer_rubrique' => 'Ph&#7893; bi&#7871;n &#273;&#7873; m&#7909;c n&agrave;y',
'syndiquer_site' => 'Ph&#7893; bi&#7871;n tr&#7885;n trang web',

// T
'texte_lettre_information' => '&#272;&acirc;y l&agrave; b&#7843;n tin c&#7911;a trang web',
'texte_lettre_information_2' => 'T&oacute;m t&#7855;t c&aacute;c b&agrave;i v&#7903; v&agrave; tin ng&#7855;n &#273;&atilde; ph&aacute;t h&agrave;nh t&#7915; ',

// V
'ver_imprimer' => 'Ki&#7875;u d&#7875; in',
'voir_en_ligne' => 'Xem online',
'voir_squelette' => 'voir le squelette de cette page', # NE
);

?>
